@@ -3,6 +3,8 @@ cruzdb: library for pythonic access to UCSC genome-browser's MySQL database
 """
 import soup
 import sys
+import os
+from sqlalchemy.orm.query import Query
 
 class BigException(Exception): pass
 
@@ -56,6 +58,8 @@ class Genome(soup.Genome):
         internal: create a dburl from a set of parameters or the defaults on
         this object
         """
+        if os.path.exists(db):
+            db = "sqlite:///" + db
 
         if db.startswith(("sqlite://", "mysql://", "postgresql://")):
 
@@ -92,7 +96,7 @@ class Genome(soup.Genome):
         from mirror import mirror
         return mirror(self, tables, dest_url)
 
-    def dataframe(self, table, limit=None, offset=None):
+    def dataframe(self, table):
         """
         create a pandas dataframe from a table or query
 
@@ -111,13 +115,15 @@ class Genome(soup.Genome):
         from pandas import DataFrame
         if isinstance(table, basestring):
             table = getattr(self, table)
-        records = table._table.select()
-        if not limit is None:
-            records = records.limit(limit)
-        if not offset is None:
-            records = records.offset(offset)
-        records = list(records.execute())
-        cols = [c.name for c in table._table.columns]
+        try:
+            rec = table.first()
+        except AttributeError:
+            rec = table[0]
+        if hasattr(table, "all"):
+            records = table.all()
+        else:
+            records = [tuple(t) for t in table]
+        cols = [c.name for c in rec._table.columns]
         return DataFrame.from_records(records, columns=cols)
 
     @property
@@ -169,7 +175,8 @@ class Genome(soup.Genome):
             if bins:
                 chunk['bin'] = 1
             if i == 0 and not table in self.tables:
-                schema = sql.get_sqlite_schema(chunk, table)
+                flavor = self.url.split(":")[0]
+                schema = sql.get_schema(chunk, table, flavor)
                 print schema
                 self.engine.execute(schema)
             elif i == 0:
